@@ -26,6 +26,15 @@ FAILEDOPERATION_APIGW = 'FailedOperation.Apigw'
 # This operation is not supported by the current async event status. Please try again later.
 FAILEDOPERATION_ASYNCEVENTSTATUS = 'FailedOperation.AsyncEventStatus'
 
+# Login information verification failed and token verification failed.
+FAILEDOPERATION_AUTHFAILURE = 'FailedOperation.AuthFailure'
+
+# Failed to query the role information.
+FAILEDOPERATION_CALLROLEFAILED = 'FailedOperation.CallRoleFailed'
+
+# 
+FAILEDOPERATION_COPYASYNCRUN = 'FailedOperation.CopyAsyncRun'
+
 # Failed to replicate the function.
 FAILEDOPERATION_COPYFAILED = 'FailedOperation.CopyFailed'
 
@@ -92,6 +101,12 @@ FAILEDOPERATION_PROVISIONCREATETIMER = 'FailedOperation.ProvisionCreateTimer'
 # Failed to delete the scheduled provisioned concurrency scaling action
 FAILEDOPERATION_PROVISIONDELETETIMER = 'FailedOperation.ProvisionDeleteTimer'
 
+# 
+FAILEDOPERATION_PROVISIONEDEXCEEDAVAILABLE = 'FailedOperation.ProvisionedExceedAvailable'
+
+# 
+FAILEDOPERATION_PROVISIONEDEXCEEDRESERVED = 'FailedOperation.ProvisionedExceedReserved'
+
 # The function version already has a provisioned concurrency setting task in progress. Please try again later.
 FAILEDOPERATION_PROVISIONEDINPROGRESS = 'FailedOperation.ProvisionedInProgress'
 
@@ -101,9 +116,15 @@ FAILEDOPERATION_PUBLISHLAYERVERSION = 'FailedOperation.PublishLayerVersion'
 # You cannot publish a version in the current function state. Please try again when the state is normal.
 FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 
+# 
+FAILEDOPERATION_RESERVEDEXCEEDTOTAL = 'FailedOperation.ReservedExceedTotal'
+
 # The function already has a reserved concurrency setting task in progress. Please try again later.
 FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 
+# 
+FAILEDOPERATION_SERVICECLOSED = 'FailedOperation.ServiceClosed'
+
 # This topic does not exsit.
 FAILEDOPERATION_TOPICNOTEXIST = 'FailedOperation.TopicNotExist'
 
@@ -146,9 +167,15 @@ INTERNALERROR_SYSTEM = 'InternalError.System'
 # The value of `FunctionName` does not conform to the specification. Please fix it and try again. For more information, please visit https://tencentcs.com/5jXKFnBW.
 INVALIDPARAMETER_FUNCTIONNAME = 'InvalidParameter.FunctionName'
 
+# Function creation parameter error.
+INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'
+
 # Invalid request parameter.
 INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'
 
+# 
+INVALIDPARAMETER_ROLECHECK = 'InvalidParameter.RoleCheck'
+
 # Incorrect `RoutingConfig` parameter.
 INVALIDPARAMETER_ROUTINGCONFIG = 'InvalidParameter.RoutingConfig'
 
@@ -221,9 +248,18 @@ INVALIDPARAMETERVALUE_DATETIME = 'InvalidParameterValue.DateTime'
 # Failed to create the default namespace.
 INVALIDPARAMETERVALUE_DEFAULTNAMESPACE = 'InvalidParameterValue.DefaultNamespace'
 
+# The code parameter of the function template corresponding with the DemoID is error.
+INVALIDPARAMETERVALUE_DEMO = 'InvalidParameterValue.Demo'
+
+# The DemoId does not exist.
+INVALIDPARAMETERVALUE_DEMOID = 'InvalidParameterValue.DemoId'
+
 # Description error.
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
+# The configuration of the environment variable DNS[OS_NAMESERVER] is incorrect.
+INVALIDPARAMETERVALUE_DNSINFO = 'InvalidParameterValue.DnsInfo'
+
 # The value of `Enable` does not conform to the specification. Please fix it and try again. For more information, please visit https://tencentcs.com/5jXKFnBW.
 INVALIDPARAMETERVALUE_ENABLE = 'InvalidParameterValue.Enable'
 
@@ -239,6 +275,12 @@ INVALIDPARAMETERVALUE_FUNCTION = 'InvalidParameterValue.Function'
 # The function does not exist.
 INVALIDPARAMETERVALUE_FUNCTIONNAME = 'InvalidParameterValue.FunctionName'
 
+# Request ID error
+INVALIDPARAMETERVALUE_FUNCTIONREQUESTID = 'InvalidParameterValue.FunctionRequestId'
+
+# FunctionType error
+INVALIDPARAMETERVALUE_FUNCTIONTYPE = 'InvalidParameterValue.FunctionType'
+
 # The format of GitBranch is incorrect. 
 INVALIDPARAMETERVALUE_GITBRANCH = 'InvalidParameterValue.GitBranch'
 
@@ -257,6 +299,9 @@ INVALIDPARAMETERVALUE_GITUSERNAME = 'InvalidParameterValue.GitUserName'
 # Handler error.
 INVALIDPARAMETERVALUE_HANDLER = 'InvalidParameterValue.Handler'
 
+# ImageType error
+INVALIDPARAMETERVALUE_IMAGETYPE = 'InvalidParameterValue.ImageType'
+
 # The input of imageUri is incorrect.
 INVALIDPARAMETERVALUE_IMAGEURI = 'InvalidParameterValue.ImageUri'
 
@@ -314,6 +359,9 @@ INVALIDPARAMETERVALUE_PROVISIONTYPE = 'InvalidParameterValue.ProvisionType'
 # Unsupported function version.
 INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'
 
+# Version parameter error
+INVALIDPARAMETERVALUE_QUERYVERSION = 'InvalidParameterValue.QueryVersion'
+
 # The value Enterprise Edition image ID [RegistryId] is incorrect.
 INVALIDPARAMETERVALUE_REGISTRYID = 'InvalidParameterValue.RegistryId'
 
@@ -407,6 +455,9 @@ LIMITEXCEEDED_LAYERVERSIONS = 'LimitExceeded.LayerVersions'
 # 
 LIMITEXCEEDED_LAYERS = 'LimitExceeded.Layers'
 
+# Reached the upper limit of dynamic scaling.
+LIMITEXCEEDED_MAXCAPACITY = 'LimitExceeded.MaxCapacity'
+
 # The memory exceeds the upper limit.
 LIMITEXCEEDED_MEMORY = 'LimitExceeded.Memory'
 
@@ -509,6 +560,9 @@ RESOURCENOTFOUND_FUNCTIONNAME = 'ResourceNotFound.FunctionName'
 # The function version does not exist.
 RESOURCENOTFOUND_FUNCTIONVERSION = 'ResourceNotFound.FunctionVersion'
 
+# Failed to find the specified `ImageConfig`. Please create it first.
+RESOURCENOTFOUND_IMAGECONFIG = 'ResourceNotFound.ImageConfig'
+
 # The layer does not exist.
 RESOURCENOTFOUND_LAYER = 'ResourceNotFound.Layer'
 
